==> jc-1.4.0.tar.gz: gnu/java/nio/NIODatagramSocket.h <==
// public final class gnu.java.nio.NIODatagramSocket

// class file dependencies
// @dep_class cb09fc2829266462 gnu_java_nio_NIODatagramSocket
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2843f4860cb0960f java_net_DatagramSocket

// header file dependencies
// @dep_header java_net_DatagramSocket

#include "java/net/DatagramSocket.h"

#ifndef _JC_gnu_java_nio_NIODatagramSocket_H_
#define _JC_gnu_java_nio_NIODatagramSocket_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainDatagramSocketImpl$object;
struct _jc_gnu_java_nio_DatagramChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_DatagramChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIODatagramSocket$sub_refs	_jc_gnu_java_nio_NIODatagramSocket$sub_refs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs	_jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$refs	_jc_gnu_java_nio_NIODatagramSocket$refs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$nonrefs	_jc_gnu_java_nio_NIODatagramSocket$nonrefs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$object	_jc_gnu_java_nio_NIODatagramSocket$object;

typedef const struct _jc_gnu_java_nio_NIODatagramSocket$vmethods	_jc_gnu_java_nio_NIODatagramSocket$vmethods;
typedef const struct _jc_gnu_java_nio_NIODatagramSocket$vtable	_jc_gnu_java_nio_NIODatagramSocket$vtable;
typedef const struct _jc_gnu_java_nio_NIODatagramSocket$vtype	_jc_gnu_java_nio_NIODatagramSocket$vtype;

// Constructors
extern void _jc_gnu_java_nio_NIODatagramSocket$method$_init$2f475a91dee78908(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *, struct _jc_gnu_java_net_PlainDatagramSocketImpl$object *, struct _jc_gnu_java_nio_DatagramChannelImpl$object *);

// Virtual methods
extern struct _jc_java_nio_channels_DatagramChannel$object *_jc_gnu_java_nio_NIODatagramSocket$method$getChannel$1421fb2fb5b36e4e(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *);
extern struct _jc_gnu_java_net_PlainDatagramSocketImpl$object *_jc_gnu_java_nio_NIODatagramSocket$method$getPlainDatagramSocketImpl$ed6cf3250c138ee5(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_NIODatagramSocket$method_info$getChannel$1421fb2fb5b36e4e;
extern _jc_method _jc_gnu_java_nio_NIODatagramSocket$method_info$getPlainDatagramSocketImpl$ed6cf3250c138ee5;

// Virtual methods structure
struct _jc_gnu_java_nio_NIODatagramSocket$vmethods {
	struct _jc_java_nio_channels_DatagramChannel$object	*(*getChannel$1421fb2fb5b36e4e)(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *);
	struct _jc_gnu_java_net_PlainDatagramSocketImpl$object	*(*getPlainDatagramSocketImpl$ed6cf3250c138ee5)(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *);
};

// Vtable
struct _jc_gnu_java_nio_NIODatagramSocket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_DatagramSocket$vmethods	java_net_DatagramSocket;
	_jc_gnu_java_nio_NIODatagramSocket$vmethods	gnu_java_nio_NIODatagramSocket;
};

// Vtype
struct _jc_gnu_java_nio_NIODatagramSocket$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIODatagramSocket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIODatagramSocket$sub_refs {
	struct _jc_gnu_java_net_PlainDatagramSocketImpl$object	*impl;
	struct _jc_gnu_java_nio_DatagramChannelImpl$object	*channel;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIODatagramSocket$refs {
    _jc_gnu_java_nio_NIODatagramSocket$sub_refs	gnu_java_nio_NIODatagramSocket;
    _jc_java_net_DatagramSocket$sub_refs	java_net_DatagramSocket;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIODatagramSocket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_DatagramSocket$sub_nonrefs	java_net_DatagramSocket;
    _jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs	gnu_java_nio_NIODatagramSocket;
};

// Object instance structure
struct _jc_gnu_java_nio_NIODatagramSocket$object {
	_jc_gnu_java_nio_NIODatagramSocket$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIODatagramSocket$vtype	*vtype;
	_jc_gnu_java_nio_NIODatagramSocket$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIODatagramSocket$vtype _jc_gnu_java_nio_NIODatagramSocket$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIODatagramSocket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIODatagramSocket$class_object;

#endif	/* _JC_gnu_java_nio_NIODatagramSocket_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/NIODatagramSocket.h <==
// public final class gnu.java.nio.NIODatagramSocket

// class file dependencies
// @dep_class cb09fc2829266462 gnu_java_nio_NIODatagramSocket
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2843f4860cb0960f java_net_DatagramSocket

// header file dependencies
// @dep_header java_net_DatagramSocket

#include "java/net/DatagramSocket.h"

#ifndef _JC_gnu_java_nio_NIODatagramSocket_H_
#define _JC_gnu_java_nio_NIODatagramSocket_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainDatagramSocketImpl$object;
struct _jc_gnu_java_nio_DatagramChannelImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_DatagramChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_NIODatagramSocket$sub_refs	_jc_gnu_java_nio_NIODatagramSocket$sub_refs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs	_jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$refs	_jc_gnu_java_nio_NIODatagramSocket$refs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$nonrefs	_jc_gnu_java_nio_NIODatagramSocket$nonrefs;
typedef struct _jc_gnu_java_nio_NIODatagramSocket$object	_jc_gnu_java_nio_NIODatagramSocket$object;

typedef const struct _jc_gnu_java_nio_NIODatagramSocket$vmethods	_jc_gnu_java_nio_NIODatagramSocket$vmethods;
typedef const struct _jc_gnu_java_nio_NIODatagramSocket$vtable	_jc_gnu_java_nio_NIODatagramSocket$vtable;
typedef const struct _jc_gnu_java_nio_NIODatagramSocket$vtype	_jc_gnu_java_nio_NIODatagramSocket$vtype;

// Constructors
extern void _jc_gnu_java_nio_NIODatagramSocket$method$_init$2f475a91dee78908(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *, struct _jc_gnu_java_net_PlainDatagramSocketImpl$object *, struct _jc_gnu_java_nio_DatagramChannelImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_DatagramChannel$object *_jc_gnu_java_nio_NIODatagramSocket$method$getChannel$1421fb2fb5b36e4e(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_java_net_PlainDatagramSocketImpl$object *_jc_gnu_java_nio_NIODatagramSocket$method$getPlainDatagramSocketImpl$ed6cf3250c138ee5(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_NIODatagramSocket$method_info$getChannel$1421fb2fb5b36e4e;
extern _jc_method _jc_gnu_java_nio_NIODatagramSocket$method_info$getPlainDatagramSocketImpl$ed6cf3250c138ee5;

// Virtual methods structure
struct _jc_gnu_java_nio_NIODatagramSocket$vmethods {
	struct _jc_java_nio_channels_DatagramChannel$object	*(*getChannel$1421fb2fb5b36e4e)(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_java_net_PlainDatagramSocketImpl$object	*(*getPlainDatagramSocketImpl$ed6cf3250c138ee5)(_jc_env *, struct _jc_gnu_java_nio_NIODatagramSocket$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_NIODatagramSocket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_DatagramSocket$vmethods	java_net_DatagramSocket;
	_jc_gnu_java_nio_NIODatagramSocket$vmethods	gnu_java_nio_NIODatagramSocket;
};

// Vtype
struct _jc_gnu_java_nio_NIODatagramSocket$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_NIODatagramSocket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_NIODatagramSocket$sub_refs {
	struct _jc_gnu_java_net_PlainDatagramSocketImpl$object	*impl;
	struct _jc_gnu_java_nio_DatagramChannelImpl$object	*channel;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_NIODatagramSocket$refs {
    _jc_gnu_java_nio_NIODatagramSocket$sub_refs	gnu_java_nio_NIODatagramSocket;
    _jc_java_net_DatagramSocket$sub_refs	java_net_DatagramSocket;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_NIODatagramSocket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_DatagramSocket$sub_nonrefs	java_net_DatagramSocket;
    _jc_gnu_java_nio_NIODatagramSocket$sub_nonrefs	gnu_java_nio_NIODatagramSocket;
};

// Object instance structure
struct _jc_gnu_java_nio_NIODatagramSocket$object {
	_jc_gnu_java_nio_NIODatagramSocket$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_NIODatagramSocket$vtype	*vtype;
	_jc_gnu_java_nio_NIODatagramSocket$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_NIODatagramSocket$vtype _jc_gnu_java_nio_NIODatagramSocket$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_NIODatagramSocket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_NIODatagramSocket$class_object;

#endif	/* _JC_gnu_java_nio_NIODatagramSocket_H_ */
